@@ -7,6 +7,7 @@ Borrowed from Brad Chapman's implementation:
 https://github.com/chapmanb/bcbio-nextgen/blob/master/bcbio/distributed/ipython.py
 """
 import contextlib
+import copy
 import math
 import os
 import pipes
@@ -21,7 +22,7 @@ import imp
 from IPython.parallel import Client
 from IPython.parallel.apps import launcher
 from IPython.parallel import error as iperror
-from IPython.utils.path import locate_profile, get_security_file
+from IPython.utils.path import locate_profile
 from IPython.utils import traitlets
 from IPython.utils.traitlets import (List, Unicode, CRegExp)
 
@@ -34,7 +35,9 @@ def _dill_installed():
     except ImportError:
         return False
 
-if _dill_installed():
+# XXX Currently disabled: needs more testing
+#if _dill_installed():
+if False:
     import dill
 
     # disable special function handling
@@ -437,21 +440,22 @@ def _scheduler_resources(scheduler, params):
     Handles SGE parallel environments, which allow multicore jobs
     but are specific to different environments.
     """
-    resources = params.get("resources", [])
+    resources = copy.deepcopy(params.get("resources", []))
+    if not resources:
+        resources = []
     if isinstance(resources, basestring):
         resources = resources.split(";")
     pename = None
     if scheduler in ["SGE"]:
+        pass_resources = []
         for r in resources:
             if r.startswith("pename="):
                 _, pename = r.split("=")
-                resources.remove(r)
-                break
+            else:
+                pass_resources.append(r)
         if pename is None:
             pename = _find_parallel_environment()
-
-    if not resources:
-        resources = []
+        resources = pass_resources
 
     return ";".join(resources), pename
 
